==> unity-ads-4.11.1-sources.jar: com/unity3d/ads/core/domain/GetAndroidLimitedSessionToken.kt <==
package com.unity3d.ads.core.domain

import com.unity3d.ads.core.data.repository.DeviceInfoRepository
import com.unity3d.ads.core.data.repository.MediationRepository
import com.unity3d.ads.core.data.repository.SessionRepository
import com.unity3d.ads.core.extensions.toUUID
import com.unity3d.services.UnityAdsConstants
import gateway.v1.ClientInfoOuterClass
import gateway.v1.UniversalRequestOuterClass.LimitedSessionToken
import gateway.v1.limitedSessionToken
import org.koin.core.annotation.Single

@Single
internal class GetAndroidLimitedSessionToken(
    private val deviceInfoRepository: DeviceInfoRepository,
    private val sessionRepository: SessionRepository,
    private val mediationRepository: MediationRepository
) : GetLimitedSessionToken {
    override suspend operator fun invoke(): LimitedSessionToken {
        return limitedSessionToken {
            deviceMake = deviceInfoRepository.staticDeviceInfo().deviceMake
            deviceModel = deviceInfoRepository.staticDeviceInfo().deviceModel
            osVersion = deviceInfoRepository.staticDeviceInfo().osVersion
            idfi = deviceInfoRepository.getIdfi().toUUID().toString()
            sdkVersion = UnityAdsConstants.ClientInfo.SDK_VERSION
            sdkVersionName = UnityAdsConstants.ClientInfo.SDK_VERSION_NAME
            gameId = sessionRepository.gameId
            platform = ClientInfoOuterClass.Platform.PLATFORM_ANDROID
            mediationProvider = mediationRepository.mediationProvider()
            mediationRepository.name?.let {
                if (mediationProvider == ClientInfoOuterClass.MediationProvider.MEDIATION_PROVIDER_CUSTOM) {
                    customMediationName = it
                }
            }
            mediationRepository.version?.let {
                mediationVersion = it
            }
        }
    }
}

==> unity-ads-4.12.0-sources.jar: com/unity3d/ads/core/domain/GetAndroidLimitedSessionToken.kt <==
package com.unity3d.ads.core.domain

import com.unity3d.ads.core.data.repository.DeviceInfoRepository
import com.unity3d.ads.core.data.repository.MediationRepository
import com.unity3d.ads.core.data.repository.SessionRepository
import com.unity3d.services.UnityAdsConstants
import gateway.v1.ClientInfoOuterClass
import gateway.v1.UniversalRequestOuterClass.LimitedSessionToken
import gateway.v1.limitedSessionToken



internal class GetAndroidLimitedSessionToken(
    private val deviceInfoRepository: DeviceInfoRepository,
    private val sessionRepository: SessionRepository,
    private val mediationRepository: MediationRepository
) : GetLimitedSessionToken {
    override suspend operator fun invoke(): LimitedSessionToken {
        return limitedSessionToken {
            deviceMake = deviceInfoRepository.staticDeviceInfo().deviceMake
            deviceModel = deviceInfoRepository.staticDeviceInfo().deviceModel
            osVersion = deviceInfoRepository.staticDeviceInfo().osVersion
            idfi = deviceInfoRepository.getIdfi()
            sdkVersion = UnityAdsConstants.ClientInfo.SDK_VERSION
            sdkVersionName = UnityAdsConstants.ClientInfo.SDK_VERSION_NAME
            gameId = sessionRepository.gameId
            platform = ClientInfoOuterClass.Platform.PLATFORM_ANDROID
            mediationProvider = mediationRepository.mediationProvider()
            mediationRepository.name?.let {
                if (mediationProvider == ClientInfoOuterClass.MediationProvider.MEDIATION_PROVIDER_CUSTOM) {
                    customMediationName = it
                }
            }
            mediationRepository.version?.let {
                mediationVersion = it
            }
        }
    }
}
